@@ -287,19 +287,19 @@ gboolean xa_get_compressed_tar_type (XArchiveType *type)
 	switch (*type)
 	{
 		case XARCHIVETYPE_BZIP2:
-			*type = XARCHIVETYPE_TAR_BZ2;
+			*type = XARCHIVETYPE_TAR_BZIP2;
 			break;
 
 		case XARCHIVETYPE_COMPRESS:
-			*type = XARCHIVETYPE_TAR_Z;
+			*type = XARCHIVETYPE_TAR_COMPRESS;
 			break;
 
 		case XARCHIVETYPE_GZIP:
-			*type = XARCHIVETYPE_TAR_GZ;
+			*type = XARCHIVETYPE_TAR_GZIP;
 			break;
 
 		case XARCHIVETYPE_LRZIP:
-			*type = XARCHIVETYPE_TAR_LRZ;
+			*type = XARCHIVETYPE_TAR_LRZIP;
 			break;
 
 		case XARCHIVETYPE_LZ4:
@@ -307,7 +307,7 @@ gboolean xa_get_compressed_tar_type (XArchiveType *type)
 			break;
 
 		case XARCHIVETYPE_LZIP:
-			*type = XARCHIVETYPE_TAR_LZ;
+			*type = XARCHIVETYPE_TAR_LZIP;
 			break;
 
 		case XARCHIVETYPE_LZMA:
@@ -359,6 +359,9 @@ XArchive *xa_init_archive_structure (ArchiveType xa)
 
 	archive->archiver = &archiver[xa.type];
 
+	if (archive_dir_treestore)
+		gtk_tree_store_clear(archive_dir_treestore);
+
 	(*archive->archiver->ask)(archive);
 
 	return archive;
@@ -399,6 +402,9 @@ void xa_spawn_async_process (XArchive *archive, const gchar *command)
 
 	g_strfreev(argv);
 
+	g_free(archive->command);
+	archive->command = g_strdup(command);
+
 	archive->child_ref = XA_CHILD_PROCS;
 
 	if (xa_main_window)
@@ -480,6 +486,7 @@ void xa_clean_archive_structure (XArchive *archive)
 	g_free(archive->extraction_dir);
 	g_free(archive->password);
 	g_free(archive->child_dir);
+	g_free(archive->command);
 	g_free(archive);
 }
 
@@ -796,11 +803,11 @@ void xa_fill_dir_sidebar(XArchive *archive,gboolean force_reload)
 {
 	GtkTreeIter iter;
 
-	if (gtk_tree_model_get_iter_first(GTK_TREE_MODEL(archive_dir_model),&iter) && force_reload == FALSE)
+	if (gtk_tree_model_get_iter_first(GTK_TREE_MODEL(archive_dir_treestore), &iter) && force_reload == FALSE)
 		return;
 
-	gtk_tree_store_clear(GTK_TREE_STORE(archive_dir_model));
-	xa_build_dir_sidebar(archive->root_entry, archive_dir_model, NULL, NULL);
+	gtk_tree_store_clear(archive_dir_treestore);
+	xa_build_dir_sidebar(archive->root_entry, archive_dir_treestore, NULL, NULL);
 }
 
 void xa_dir_sidebar_row_selected (GtkTreeSelection *selection, gpointer user_data)
@@ -845,7 +852,7 @@ void xa_dir_sidebar_row_selected (GtkTreeSelection *selection, gpointer user_dat
 
 void xa_dir_sidebar_select_row (XEntry *entry)
 {
-	gtk_tree_model_foreach(GTK_TREE_MODEL(archive_dir_model), xa_dir_sidebar_find_row, entry);
+	gtk_tree_model_foreach(GTK_TREE_MODEL(archive_dir_treestore), xa_dir_sidebar_find_row, entry);
 }
 
 gint xa_sort_dirs_before_files (GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, XArchive *archive)
