@@ -24,11 +24,11 @@ typedef enum
 {
 	XARCHIVETYPE_FIRST,
 	XARCHIVETYPE_7ZIP = XARCHIVETYPE_FIRST,
+	XARCHIVETYPE_AR,
 	XARCHIVETYPE_ARJ,
 	XARCHIVETYPE_BZIP2,
 	XARCHIVETYPE_COMPRESS,
 	XARCHIVETYPE_CPIO,
-	XARCHIVETYPE_DEB,
 	XARCHIVETYPE_GZIP,
 	XARCHIVETYPE_LHA,
 	XARCHIVETYPE_LRZIP,
@@ -39,15 +39,15 @@ typedef enum
 	XARCHIVETYPE_RAR,
 	XARCHIVETYPE_RPM,
 	XARCHIVETYPE_TAR,
-	XARCHIVETYPE_TAR_BZ2,
-	XARCHIVETYPE_TAR_GZ,
-	XARCHIVETYPE_TAR_LRZ,
-	XARCHIVETYPE_TAR_LZ,
+	XARCHIVETYPE_TAR_BZIP2,
+	XARCHIVETYPE_TAR_COMPRESS,
+	XARCHIVETYPE_TAR_GZIP,
+	XARCHIVETYPE_TAR_LRZIP,
 	XARCHIVETYPE_TAR_LZ4,
+	XARCHIVETYPE_TAR_LZIP,
 	XARCHIVETYPE_TAR_LZMA,
 	XARCHIVETYPE_TAR_LZOP,
 	XARCHIVETYPE_TAR_XZ,
-	XARCHIVETYPE_TAR_Z,
 	XARCHIVETYPE_TAR_ZSTD,
 	XARCHIVETYPE_XZ,
 	XARCHIVETYPE_ZIP,
@@ -189,6 +189,7 @@ struct _XArchive
 	guint child_ref;
 	gint child_fdout;
 	gint child_fderr;
+	gchar *command;       // (free before use)
 	GSList *output;
 	/* (un)compressor interface */
 	XArchiver *archiver;
