@@ -290,7 +290,7 @@ Extract_dialog_data *xa_create_extract_dialog()
 	GSList *radiobutton1_group;
 	Extract_dialog_data *dialog_data;
 	GtkWidget *hbox1, *hbox2, *hbox3, *vbox1, *vbox2, *vbox3, *vbox5, *alignment, *alignment1, *alignment2, *alignment3, *label1, *label2, *label3;
-	GtkWidget *frame1, *frame2, *dialog_action_area1;
+	GtkWidget *frame1, *frame2;
 	GtkWidget *cancel_button, *extract_button, *extract_image, *extract_hbox, *extract_label;
 
 	dialog_data = g_new0 (Extract_dialog_data,1);
@@ -313,6 +313,7 @@ Extract_dialog_data *xa_create_extract_dialog()
 	dialog_data->destination_path_entry = GTK_COMPAT_ENTRY_ICON_NEW();
 	GTK_COMPAT_ENTRY_ICON(dialog_data->destination_path_entry, xa_select_where_to_extract, dialog_data);
 	gtk_box_pack_start (GTK_BOX (vbox1),dialog_data->destination_path_entry,FALSE,FALSE,0);
+	gtk_entry_set_activates_default(GTK_ENTRY(dialog_data->destination_path_entry), TRUE);
 
 	alignment = gtk_alignment_new(0.5, 0.5, 1, 1);
 	gtk_alignment_set_padding(GTK_ALIGNMENT(alignment), 0, 0, 14, 0);
@@ -408,13 +409,10 @@ Extract_dialog_data *xa_create_extract_dialog()
 	dialog_data->password_entry = gtk_entry_new ();
 	gtk_box_pack_start (GTK_BOX (hbox3),dialog_data->password_entry,TRUE,TRUE,0);
 	gtk_entry_set_visibility (GTK_ENTRY (dialog_data->password_entry),FALSE);
-
-	dialog_action_area1 = gtk_dialog_get_action_area(GTK_DIALOG(dialog_data->dialog1));
-	gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area1),GTK_BUTTONBOX_END);
+	gtk_entry_set_activates_default(GTK_ENTRY(dialog_data->password_entry), TRUE);
 
 	cancel_button = gtk_button_new_from_stock(GTK_STOCK_CANCEL);
 	gtk_dialog_add_action_widget (GTK_DIALOG (dialog_data->dialog1),cancel_button,GTK_RESPONSE_CANCEL);
-	gtk_widget_set_can_default(cancel_button, TRUE);
 
 	extract_button = gtk_button_new();
 	extract_image = xa_main_window_find_image("xarchiver-extract.png",GTK_ICON_SIZE_SMALL_TOOLBAR);
@@ -478,8 +476,7 @@ void xa_set_extract_dialog_options(Extract_dialog_data *dialog_data,gint selecte
 	}
 	g_free(archive_dir);
 
-	if (archive->password)
-		gtk_entry_set_text(GTK_ENTRY(dialog_data->password_entry), archive->password);
+	gtk_entry_set_text(GTK_ENTRY(dialog_data->password_entry), archive->password ? archive->password : "");
 
 	gtk_widget_set_sensitive(label_password, archive->has_password);
 	gtk_widget_set_sensitive(dialog_data->password_entry, archive->has_password);
@@ -526,7 +523,7 @@ void xa_parse_extract_dialog_options (XArchive *archive,Extract_dialog_data *dia
 				g_free(extraction_dir);
 				g_free (cur_dir);
 			}
-			if (archive->has_password || (xa_main_window == FALSE && strlen(gtk_entry_get_text(GTK_ENTRY(dialog_data->password_entry))) > 0))
+			if (archive->has_password)
 				archive->password  = g_strdup(gtk_entry_get_text(GTK_ENTRY(dialog_data->password_entry)));
 
 			if (archive->has_password && strlen(archive->password)== 0 )
@@ -621,7 +618,7 @@ Multi_extract_data *xa_create_multi_extract_dialog()
 	GTK_COMPAT_TOOLTIPS;
 	Multi_extract_data *dialog_data;
 	GtkWidget	*dialog_vbox1,*vbox1,*scrolledwindow1,*hbox1,*frame1,*alignment1,*vbox2,*hbox3,*remove_button,*add_button,*cancelbutton1;
-	GtkWidget *hbox2, *vbox3, *alignment2, *alignment3, *label1, *label2, *frame2, *dialog_action_area1;
+	GtkWidget *hbox2, *vbox3, *alignment2, *alignment3, *label1, *label2, *frame2;
 	GtkWidget *extract_button, *extract_image, *extract_hbox, *extract_label;
 	GtkCellRenderer *renderer;
 	GtkTreeSelection *selection;
@@ -705,6 +702,7 @@ Multi_extract_data *xa_create_multi_extract_dialog()
 	dialog_data->entry1 = GTK_COMPAT_ENTRY_ICON_NEW();
 	GTK_COMPAT_ENTRY_ICON(dialog_data->entry1, xa_select_where_to_extract, dialog_data);
 	gtk_box_pack_start (GTK_BOX (hbox3),dialog_data->entry1,TRUE,TRUE,0);
+	gtk_entry_set_activates_default(GTK_ENTRY(dialog_data->entry1), TRUE);
 
 	dialog_data->extract_to_archive_name = gtk_radio_button_new_with_mnemonic(radiobutton1_group, _("Extract to dir \"Archive Name\""));
 	gtk_widget_set_tooltip_text(dialog_data->extract_to_archive_name, _("This option extracts archives in directories named with the archive names"));
@@ -729,11 +727,8 @@ Multi_extract_data *xa_create_multi_extract_dialog()
 	label2 = gtk_label_new (_("Options:"));
 	gtk_frame_set_label_widget(GTK_FRAME(frame2),label2);
 
-	dialog_action_area1 = gtk_dialog_get_action_area(GTK_DIALOG(dialog_data->multi_extract));
-	gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area1),GTK_BUTTONBOX_END);
 	cancelbutton1 = gtk_button_new_from_stock ("gtk-cancel");
 	gtk_dialog_add_action_widget (GTK_DIALOG (dialog_data->multi_extract),cancelbutton1,GTK_RESPONSE_CANCEL);
-	gtk_widget_set_can_default(cancelbutton1, TRUE);
 
 	extract_button = gtk_button_new();
 	extract_image = xa_main_window_find_image("xarchiver-extract.png",GTK_ICON_SIZE_SMALL_TOOLBAR);
