@@ -31,7 +31,7 @@ typedef struct Extract_dialog_data
 
 typedef struct Multi_extract_data
 {
-	GtkWidget *multi_extract,*files_treeview,*hbox2,*extract_to,*entry1,*extract_to_archive_name,*label1,*frame2,*alignment2,*vbox3,*overwrite,*full_path,*label2,*dialog_action_area1,
+	GtkWidget *multi_extract, *files_treeview, *hbox2, *extract_to, *entry1, *extract_to_archive_name, *label1, *frame2, *alignment2, *vbox3, *overwrite, *full_path, *label2,
 	*extract_button,*extract_image,*extract_hbox,*extract_label,*image1;
 	GtkListStore *files_liststore;
 	gint nr;
