@@ -145,7 +145,7 @@ static void xa_gzip_et_al_parse_output (gchar *line, XArchive *archive)
 	if (archive->type == XARCHIVETYPE_GZIP)
 	{
 		/* heading? */
-		if (line[9] == 'c')
+		if (line[9] == 'c' || line[0] == 'c')   // genuine gzip or pigz
 			return;
 	}
 	else if (archive->type == XARCHIVETYPE_LZIP)
