@@ -71,7 +71,7 @@ GtkWidget *view_shell_output1;
 GtkWidget *xa_popup_menu;
 GtkAccelGroup *accel_group;
 GtkNotebook *notebook;
-GtkTreeStore *archive_dir_model;
+GtkTreeStore *archive_dir_treestore;
 Progress *progress;
 
 static GtkWidget *addfile;
@@ -417,7 +417,6 @@ static void xa_select_by_pattern_dialog (GtkMenuItem *menuitem, gpointer user_da
 	GtkWidget *dhbox1;
 	GtkWidget *pattern_label;
 	GtkWidget *pattern_entry;
-	GtkWidget *dialog_action_area1;
 	GtkWidget *cancelbutton1;
 	GtkWidget *okbutton1;
 	GtkWidget *tmp_image,*select_hbox,*select_label;
@@ -452,14 +451,9 @@ static void xa_select_by_pattern_dialog (GtkMenuItem *menuitem, gpointer user_da
 	gtk_box_pack_start (GTK_BOX (dhbox1),pattern_entry,TRUE,TRUE,0);
 	gtk_entry_set_activates_default(GTK_ENTRY(pattern_entry),TRUE);
 
-	dialog_action_area1 = gtk_dialog_get_action_area(GTK_DIALOG(ddialog1));
-	gtk_widget_show (dialog_action_area1);
-	gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area1),GTK_BUTTONBOX_END);
-
 	cancelbutton1 = gtk_button_new_from_stock ("gtk-cancel");
 	gtk_widget_show (cancelbutton1);
 	gtk_dialog_add_action_widget (GTK_DIALOG (ddialog1),cancelbutton1,GTK_RESPONSE_CANCEL);
-	gtk_widget_set_can_default(cancelbutton1, TRUE);
 
 	okbutton1 = gtk_button_new();
 	tmp_image = gtk_image_new_from_stock ("gtk-ok",GTK_ICON_SIZE_BUTTON);
@@ -532,7 +526,9 @@ static void xa_handle_navigation_buttons (GtkToolButton *button, gpointer data)
 			if (gtk_tree_selection_get_selected(selection, &model, &iter))
 				gtk_tree_selection_unselect_iter(selection,&iter);
 
+			xa_block_signal_dir_treeview_selection(TRUE);
 			xa_update_window_with_archive_entries(archive[idx],NULL);
+			xa_block_signal_dir_treeview_selection(FALSE);
 			xa_restore_navigation(idx);
 		break;
 		/* Back */
@@ -1033,14 +1029,14 @@ void xa_create_main_window (GtkWidget *xa_main_window, gboolean show_location, g
   	gtk_paned_pack1 (GTK_PANED (hpaned1),scrolledwindow2,FALSE,TRUE);
 	g_object_set (G_OBJECT (scrolledwindow2),"hscrollbar-policy",GTK_POLICY_AUTOMATIC,"shadow-type",GTK_SHADOW_IN,"vscrollbar-policy",GTK_POLICY_AUTOMATIC,NULL);
 
-  	archive_dir_model = gtk_tree_store_new (3,G_TYPE_STRING,G_TYPE_STRING,G_TYPE_POINTER);
-	archive_dir_treeview = gtk_tree_view_new_with_model(GTK_TREE_MODEL(archive_dir_model));
+	archive_dir_treestore = gtk_tree_store_new(3, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_POINTER);
+	archive_dir_treeview = gtk_tree_view_new_with_model(GTK_TREE_MODEL(archive_dir_treestore));
 	gtk_container_add (GTK_CONTAINER (scrolledwindow2),archive_dir_treeview);
 	gtk_widget_show(archive_dir_treeview);
-	gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(archive_dir_model),1,GTK_SORT_ASCENDING);
+	gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(archive_dir_treestore), 1, GTK_SORT_ASCENDING);
 	gtk_tree_view_enable_model_drag_dest(GTK_TREE_VIEW(archive_dir_treeview), drop_targets, 1, GDK_ACTION_COPY);
-	g_signal_connect (G_OBJECT (archive_dir_treeview),"row-collapsed",G_CALLBACK(xa_dir_sidebar_row_expanded),archive_dir_model);
-	g_signal_connect(G_OBJECT(archive_dir_treeview), "row-expanded", G_CALLBACK(xa_dir_sidebar_row_expanded), archive_dir_model);
+	g_signal_connect(G_OBJECT(archive_dir_treeview), "row-collapsed", G_CALLBACK(xa_dir_sidebar_row_expanded), archive_dir_treestore);
+	g_signal_connect(G_OBJECT(archive_dir_treeview), "row-expanded", G_CALLBACK(xa_dir_sidebar_row_expanded), archive_dir_treestore);
 	g_signal_connect(G_OBJECT(archive_dir_treeview), "drag-data-received", G_CALLBACK(xa_dir_sidebar_drag_data_received), NULL);
 	g_signal_connect(G_OBJECT(archive_dir_treeview), "drag-motion", G_CALLBACK(xa_dir_sidebar_drag_motion), NULL);
 	GtkTreeSelection *sel = gtk_tree_view_get_selection(GTK_TREE_VIEW (archive_dir_treeview));
@@ -1094,13 +1090,13 @@ void xa_create_main_window (GtkWidget *xa_main_window, gboolean show_location, g
 	gtk_widget_show (selected_label);
 	gtk_container_add (GTK_CONTAINER (selected_frame),selected_label);
 
-	green_led = gtk_image_new_from_icon_name ("gtk-yes",GTK_ICON_SIZE_BUTTON);
+	green_led = xa_main_window_find_image("xarchiver-green.png", GTK_ICON_SIZE_BUTTON);
 	gtk_widget_show (green_led);
 	gtk_box_pack_start (GTK_BOX (hbox_sb),green_led,FALSE,FALSE,0);
 	gtk_misc_set_alignment (GTK_MISC (green_led),1,1);
 	gtk_widget_set_tooltip_text(green_led, _("This is Xarchiver's LED status. When it's flashing Xarchiver is busy."));
 
-	red_led = gtk_image_new_from_icon_name ("gtk-no",GTK_ICON_SIZE_BUTTON);
+	red_led = xa_main_window_find_image("xarchiver-red.png", GTK_ICON_SIZE_BUTTON);
 	gtk_box_pack_start (GTK_BOX (hbox_sb),red_led,FALSE,FALSE,0);
 	gtk_misc_set_alignment (GTK_MISC (red_led),1,1);
 
@@ -1624,10 +1620,10 @@ void xa_show_progress_bar (XArchive *archive)
 
 		action_area = gtk_hbutton_box_new ();
 		gtk_button_box_set_layout (GTK_BUTTON_BOX (action_area),GTK_BUTTONBOX_END);
-  		gtk_box_pack_end (GTK_BOX (vbox2),action_area,FALSE, TRUE, 0);
+		gtk_box_pack_end(GTK_BOX(vbox2), action_area, FALSE, TRUE, 14);
 
 		cancel_button = gtk_button_new_from_stock ("gtk-cancel");
-		gtk_box_pack_end (GTK_BOX (action_area),cancel_button,TRUE,TRUE,12);
+		gtk_box_pack_end(GTK_BOX(action_area), cancel_button, TRUE, TRUE, 0);
 
 		g_signal_connect(G_OBJECT(cancel_button), "clicked", G_CALLBACK(xa_cancel_progress_bar), &archive->child_pid);
 		g_signal_connect(G_OBJECT(progress->window), "delete-event", G_CALLBACK(xa_close_progress_bar), &archive->child_pid);
