@@ -22,9 +22,9 @@
 #include "main.h"
 #include "7zip.h"
 #include "add_dialog.h"
+#include "ar.h"
 #include "arj.h"
 #include "cpio.h"
-#include "deb.h"
 #include "extract_dialog.h"
 #include "interface.h"
 #include "lha.h"
@@ -56,8 +56,8 @@ Extract_dialog_data *extract_window;
 Multi_extract_data *multi_extract_window;
 Prefs_dialog_data *prefs_window;
 
-static gchar *opt_extract_path, *opt_ensure_dir, *opt_compress;
-static gboolean opt_extract, opt_multi_extract, opt_add, opt_info, opt_version;
+static gchar *opt_extract_path, *opt_compress;
+static gboolean opt_extract, opt_ensure_dir, opt_multi_extract, opt_add, opt_info, opt_version;
 
 static GOptionEntry entries[] =
 {
@@ -97,7 +97,7 @@ static GOptionEntry entries[] =
 static void xa_check_available_archivers ()
 {
 	XArchiveType type;
-	gchar *path, *cpio, *lsar, *sevenz, *unar, *xz, *zstd;
+	gchar *path, *cpio, *lbzip2, *lsar, *pbzip2, *pigz, *plzip, *sevenz, *unar, *xz, *zstd;
 	gboolean is7z = TRUE, is7za = TRUE, is7zr = TRUE, standard;
 
 	/* (un)compressors that can handle various types */
@@ -120,7 +120,11 @@ static void xa_check_available_archivers ()
 	}
 
 	cpio = g_find_program_in_path("cpio");
+	lbzip2 = g_find_program_in_path("lbzip2");
 	lsar = g_find_program_in_path("lsar");
+	pbzip2 = g_find_program_in_path("pbzip2");
+	pigz = g_find_program_in_path("pigz");
+	plzip = g_find_program_in_path("plzip");
 	unar = g_find_program_in_path("unar");
 	xz = g_find_program_in_path("xz");
 	zstd = xa_gzip_et_al_check_zstd("zstd", "unzstd", &archiver[XARCHIVETYPE_ZSTD].is_compressor);
@@ -148,6 +152,9 @@ static void xa_check_available_archivers ()
 		archiver[type].is_compressor = standard;
 		archiver[type].type = g_slist_append(archiver[type].type, "7zip");
 		archiver[type].glob = g_slist_append(archiver[type].glob, "*.7z");
+		/* self-extracting Nullsoft Installer */
+		archiver[type].tags = g_slist_append(archiver[type].tags, GUINT_TO_POINTER('n'));
+		archiver[type].tags = g_slist_append(archiver[type].tags, _("Nullsoft Installer"));
 
 		archiver[type].ask = (standard ? xa_7zip_ask : xa_unar_ask);
 		archiver[type].list = (standard ? xa_7zip_list : xa_unar_list);
@@ -157,6 +164,43 @@ static void xa_check_available_archivers ()
 		archiver[type].delete = (standard ? xa_7zip_delete : NULL);
 	}
 
+	/* archiver */
+
+	type = XARCHIVETYPE_AR;
+	path = g_find_program_in_path("ar");
+
+	standard = (path != NULL);
+
+	if (!standard)
+	{
+		if (lsar && unar)
+		{
+			/* alternative ... */
+			path = g_strdup(lsar);
+			/* ... uncompressor */
+			archiver[type].program[1] = g_strdup(unar);
+		}
+		else if (is7z)
+			/* alternative uncompressor */
+			path = g_strconcat(sevenz, " -tar", NULL);
+	}
+
+	if (path)
+	{
+		archiver[type].program[0] = path;
+		archiver[type].type = g_slist_append(archiver[type].type, "ar");
+		archiver[type].glob = g_slist_append(archiver[type].glob, "*.a");
+		/* debian package */
+		archiver[type].type = g_slist_append(archiver[type].type, "deb");
+		archiver[type].glob = g_slist_append(archiver[type].glob, "*.deb");
+		archiver[type].tags = g_slist_append(archiver[type].tags, GUINT_TO_POINTER('d'));
+		archiver[type].tags = g_slist_append(archiver[type].tags, g_slist_last(archiver[type].type)->data);
+
+		archiver[type].ask = FUNC(standard, xa_ar_ask, lsar && unar, xa_unar_ask, is7z, xa_7zip_ask);
+		archiver[type].list = FUNC(standard, xa_ar_list, lsar && unar, xa_unar_list, is7z, xa_7zip_list);
+		archiver[type].extract  = FUNC(standard, xa_ar_extract, lsar && unar, xa_unar_extract, is7z, xa_7zip_extract);
+	}
+
 	/* ARJ */
 
 	type = XARCHIVETYPE_ARJ;
@@ -213,7 +257,23 @@ static void xa_check_available_archivers ()
 
 	if (!standard)
 	{
-		if (is7za)
+		if (lbzip2)
+		{
+			g_free(path);
+			/* alternative compressor */
+			path = g_strdup(lbzip2);
+			archiver[type].is_compressor = TRUE;
+			standard = TRUE;
+		}
+		else if (pbzip2)
+		{
+			g_free(path);
+			/* alternative compressor */
+			path = g_strdup(pbzip2);
+			archiver[type].is_compressor = TRUE;
+			standard = TRUE;
+		}
+		else if (is7za)
 		{
 			g_free(path);
 			/* alternative compressor */
@@ -324,38 +384,6 @@ static void xa_check_available_archivers ()
 		archiver[type].add = FUNC(standard, xa_cpio_add, is7z, NULL, lsar, NULL);
 	}
 
-	/* debian package */
-
-	type = XARCHIVETYPE_DEB;
-	path = g_find_program_in_path("ar");
-
-	standard = (path != NULL);
-
-	if (!standard)
-	{
-		if (lsar && unar)
-		{
-			/* alternative ... */
-			path = g_strdup(lsar);
-			/* ... uncompressor */
-			archiver[type].program[1] = g_strdup(unar);
-		}
-		else if (is7z)
-			/* alternative uncompressor */
-			path = g_strconcat(sevenz, " -tar", NULL);
-	}
-
-	if (path)
-	{
-		archiver[type].program[0] = path;
-		archiver[type].type = g_slist_append(archiver[type].type, "deb");
-		archiver[type].glob = g_slist_append(archiver[type].glob, "*.deb");
-
-		archiver[type].ask = FUNC(standard, xa_deb_ask, lsar && unar, xa_unar_ask, is7z, xa_7zip_ask);
-		archiver[type].list = FUNC(standard, xa_deb_list, lsar && unar, xa_unar_list, is7z, xa_7zip_list);
-		archiver[type].extract  = FUNC(standard, xa_deb_extract, lsar && unar, xa_unar_extract, is7z, xa_7zip_extract);
-	}
-
 	/* GNU zip */
 
 	type = XARCHIVETYPE_GZIP;
@@ -370,7 +398,15 @@ static void xa_check_available_archivers ()
 
 	if (!standard)
 	{
-		if (is7za)
+		if (pigz)
+		{
+			g_free(path);
+			/* alternative compressor */
+			path = g_strdup(pigz);
+			archiver[type].is_compressor = TRUE;
+			standard = TRUE;
+		}
+		else if (is7za)
 		{
 			g_free(path);
 			/* alternative compressor */
@@ -494,6 +530,10 @@ static void xa_check_available_archivers ()
 	type = XARCHIVETYPE_LZIP;
 	path = g_find_program_in_path("lzip");
 
+	if (!path && plzip)
+		/* alternative compressor */
+		path = g_strdup(plzip);
+
 	if (path)
 	{
 		archiver[type].program[0] = path;
@@ -881,7 +921,7 @@ static void xa_check_available_archivers ()
 			{XARCHIVETYPE_LZMA, {"tar.lzma", NULL}, {"*.tar.lzma", "*.tlz"}},
 			{XARCHIVETYPE_LZOP, {"tar.lzop", NULL}, {"*.tar.lzo", "*.tzo"}},
 			{XARCHIVETYPE_XZ, {"tar.xz", NULL}, {"*.tar.xz", "*.txz"}},
-			{XARCHIVETYPE_ZSTD, {"tar.zstd", NULL}, {"*.tar.zst", ""}},
+			{XARCHIVETYPE_ZSTD, {"tar.zstd", NULL}, {"*.tar.zst", "*.tzst"}},
 			{XARCHIVETYPE_UNKNOWN, {NULL, NULL}, {NULL, NULL}}
 		}, *i;
 
@@ -913,7 +953,11 @@ static void xa_check_available_archivers ()
 		}
 	}
 
+	g_free(lbzip2);
 	g_free(lsar);
+	g_free(pbzip2);
+	g_free(pigz);
+	g_free(plzip);
 	g_free(unar);
 }
 
@@ -963,7 +1007,6 @@ int main (int argc, char **argv)
 {
 	GError *cli_error = NULL;
 	XArchive *archive;
-	gboolean no_bzip2_gzip;
 	gchar *current_dir;
 	int i, result = -1;
 
@@ -1058,9 +1101,10 @@ int main (int argc, char **argv)
 			if (opt_ensure_dir)
 			{
 				current_dir = g_get_current_dir();
-				archive->extraction_dir = xa_escape_bad_chars(current_dir, ESCAPES);
 
-				if (!xa_has_containing_directory(archive))
+				if (xa_has_containing_directory(archive))
+					extraction_dir = xa_escape_bad_chars(current_dir, ESCAPES);
+				else
 				{
 					extraction_dir = xa_create_containing_directory(archive, current_dir);
 
@@ -1070,11 +1114,9 @@ int main (int argc, char **argv)
 						g_free(current_dir);
 						goto leave;
 					}
-
-					g_free(archive->extraction_dir);
-					opt_extract_path = extraction_dir;
 				}
 
+				opt_extract_path = extraction_dir;
 				g_free(current_dir);
 			}
 
@@ -1135,11 +1177,8 @@ int main (int argc, char **argv)
 		/* Switch -c */
 		else if (opt_compress)
 		{
-			if (argc > 1 || g_file_test (argv[1],G_FILE_TEST_IS_DIR))
-				no_bzip2_gzip = TRUE;
-			else
-				no_bzip2_gzip = FALSE;
-			archive = xa_new_archive_dialog(opt_compress, NULL, no_bzip2_gzip);
+			archive = xa_new_archive_dialog(opt_compress, NULL);
+
 			if (archive == NULL)
 				goto leave;
 
