@@ -77,6 +77,7 @@ const char *xa_get_stock_mime_icon(const char *filename)
 	         strcmp(mime,"application/vnd.openofficeorg.extension") == 0 ||
 	         strcmp(mime,"application/vnd.rar") == 0 || /* legacy */ strcmp(mime,"application/x-rar") == 0 ||
 	         strcmp(mime,"application/x-7z-compressed") == 0 ||
+	         strcmp(mime,"application/x-archive") == 0 ||
 	         strcmp(mime,"application/x-arj") == 0 ||
 	         strcmp(mime,"application/x-bzip") == 0 ||
 	         strcmp(mime,"application/x-bzip-compressed-tar") == 0 ||
@@ -103,9 +104,9 @@ const char *xa_get_stock_mime_icon(const char *filename)
 	         strcmp(mime,"application/x-xpinstall") == 0 ||
 	         strcmp(mime,"application/x-xz") == 0 ||
 	         strcmp(mime,"application/x-xz-compressed-tar") == 0 ||
+	         strcmp(mime,"application/x-zstd-compressed-tar") == 0 ||
 	         strcmp(mime,"application/zip") == 0 ||
 	         strcmp(mime,"application/zstd") == 0)
-	         // currently no type for zstd compressed tar
 		return "package-x-generic";
 	else if (strcmp(mime,"application/x-cd-image") == 0)
 		return "media-optical";
