@@ -338,7 +338,7 @@ void xa_create_open_with_dialog (const gchar *filename, gchar *filenames, gint n
 {
 	Open_with_data *data = NULL;
 	GtkListStore *apps_liststore;
-	GtkWidget	*dialog_vbox1,*vbox1,*hbox1,*mime_icon,*open_text,*scrolledwindow1,*apps_treeview,*dialog_action_area1,
+	GtkWidget *dialog_vbox1, *vbox1, *hbox1, *mime_icon, *open_text, *scrolledwindow1, *apps_treeview,
 				*custom_command_expander,*hbox_expander,*browse,*cancelbutton1,*okbutton1;
 	GtkCellRenderer		*renderer;
 	GtkTreeViewColumn	*column;
@@ -366,7 +366,7 @@ void xa_create_open_with_dialog (const gchar *filename, gchar *filenames, gint n
 	gtk_window_set_type_hint (GTK_WINDOW (data->dialog1), GDK_WINDOW_TYPE_HINT_DIALOG);
 	gtk_window_set_transient_for(GTK_WINDOW(data->dialog1),GTK_WINDOW(xa_main_window));
 	gtk_container_set_border_width (GTK_CONTAINER (data->dialog1),5);
-	gtk_widget_set_size_request(data->dialog1, 380, 425);
+	gtk_widget_set_size_request(data->dialog1, 380, 460);
 	dialog_vbox1 = gtk_dialog_get_content_area(GTK_DIALOG(data->dialog1));
 
 	vbox1 = gtk_vbox_new (FALSE, 5);
@@ -438,13 +438,9 @@ void xa_create_open_with_dialog (const gchar *filename, gchar *filenames, gint n
 	gtk_box_pack_start (GTK_BOX (hbox_expander),browse,FALSE,TRUE,0);
 	gtk_container_add(GTK_CONTAINER(custom_command_expander),hbox_expander);
 
-	dialog_action_area1 = gtk_dialog_get_action_area(GTK_DIALOG(data->dialog1));
-	gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area1),GTK_BUTTONBOX_END);
-
 	cancelbutton1 = gtk_button_new_from_stock ("gtk-cancel");
 	gtk_widget_show (cancelbutton1);
 	gtk_dialog_add_action_widget (GTK_DIALOG (data->dialog1),cancelbutton1,GTK_RESPONSE_CANCEL);
-	gtk_widget_set_can_default(cancelbutton1, TRUE);
 	g_signal_connect_swapped (G_OBJECT (cancelbutton1),"clicked",G_CALLBACK (gtk_widget_destroy),G_OBJECT(data->dialog1));
 
 	okbutton1 = gtk_button_new_from_stock ("gtk-open");
@@ -452,6 +448,7 @@ void xa_create_open_with_dialog (const gchar *filename, gchar *filenames, gint n
 	gtk_dialog_add_action_widget (GTK_DIALOG (data->dialog1),okbutton1,GTK_RESPONSE_OK);
 	g_signal_connect (G_OBJECT (okbutton1),"clicked",G_CALLBACK (xa_open_with_dialog_execute_command),data);
 	gtk_widget_set_can_default(okbutton1, TRUE);
+	gtk_widget_grab_default(okbutton1);
 	gtk_widget_show_all(data->dialog1);
 
 	/* let's parse the desktop files in the user data dir */
