@@ -27,6 +27,7 @@
 #include <sys/stat.h>
 #include "window.h"
 #include "add_dialog.h"
+#include "exe.h"
 #include "extract_dialog.h"
 #include "interface.h"
 #include "main.h"
@@ -41,6 +42,8 @@
 #ifdef __APPLE__
 #include <libkern/OSByteOrder.h>
 #define le32toh(x) OSSwapLittleToHostInt32(x)
+#elif defined(__FreeBSD__)
+#include <sys/endian.h>
 #else
 #include <endian.h>
 #endif
@@ -831,6 +834,12 @@ void xa_child_processed (XAChildProcess process, gboolean success, XArchive *arc
 		}
 		else
 		{
+			if (xa_main_window && archive->parse_output)
+			{
+				xa_update_window_with_archive_entries(archive, NULL);
+				archive->parse_output = NULL;
+			}
+
 			if (xa_main_window && !gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(prefs_window->store_output)))
 				xa_show_message_dialog(GTK_WINDOW(xa_main_window), GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, _("An error occurred!"), _("Please check the 'Store archiver output' option to see it."));
 			else
@@ -855,8 +864,6 @@ void xa_reload_archive_content (XArchive *this_archive)
 {
 	XEntry *entry;
 
-	//TODO: have the status bar notyfing the reload
-
 	g_slist_free(this_archive->forward);
 	this_archive->forward = NULL;
 
@@ -872,6 +879,8 @@ void xa_reload_archive_content (XArchive *this_archive)
 	entry->filename = "";
 	this_archive->root_entry = entry;
 
+	gtk_label_set_text(GTK_LABEL(total_label), _("Reloading archive, please wait..."));
+
 	/* this reload will be called internally during adding and deleting */
 	this_archive->status = XARCHIVESTATUS_RELOAD;
 	(*this_archive->archiver->list)(this_archive);
@@ -880,10 +889,11 @@ void xa_reload_archive_content (XArchive *this_archive)
 void xa_show_archive_output (GtkMenuItem *menuitem, XArchive *this_archive)
 {
 	GSList *output = NULL;
-	gchar *title = NULL;
-	GtkWidget *dialog,*label,*image,*hbox,*vbox,*textview,*scrolledwindow;
+	gchar *title = NULL, *cmd;
+	GtkWidget *dialog, *show_cmd, *label, *image, *hbox, *vbox, *textview, *scrolledwindow;
 	GtkTextBuffer *textbuffer;
 	GtkTextIter iter;
+	gint response;
 
 	if (this_archive == NULL)
 	{
@@ -898,8 +908,11 @@ void xa_show_archive_output (GtkMenuItem *menuitem, XArchive *this_archive)
 		title = _("Archiver output");
 	else
 		title = PACKAGE_NAME " " VERSION;
-	dialog = gtk_dialog_new_with_buttons (title,
-					      GTK_WINDOW(xa_main_window),GTK_DIALOG_MODAL,GTK_STOCK_OK,GTK_RESPONSE_OK,NULL);
+
+	dialog = gtk_dialog_new_with_buttons(title, GTK_WINDOW(xa_main_window), GTK_DIALOG_MODAL, NULL, NULL);
+
+	show_cmd = gtk_dialog_add_button(GTK_DIALOG(dialog), _("Show command"), GTK_RESPONSE_APPLY);
+	gtk_dialog_add_button(GTK_DIALOG(dialog), GTK_STOCK_OK, GTK_RESPONSE_OK);
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog),GTK_RESPONSE_OK);
 
 	gtk_container_set_border_width (GTK_CONTAINER (dialog),6);
@@ -945,7 +958,20 @@ void xa_show_archive_output (GtkMenuItem *menuitem, XArchive *this_archive)
 		output = output->next;
 	}
 	gtk_widget_show_all (vbox);
-	gtk_dialog_run (GTK_DIALOG (dialog));
+
+run_dialog:
+	response = gtk_dialog_run(GTK_DIALOG(dialog));
+
+	if (response == GTK_RESPONSE_APPLY)
+	{
+		gtk_text_buffer_get_iter_at_offset(textbuffer, &iter, 0);
+		cmd = g_strdup_printf("%s: %s\n\n", _("Command"), this_archive->command);
+		gtk_text_buffer_insert_with_tags_by_name(textbuffer, &iter, cmd, -1, "font", NULL);
+		g_free(cmd);
+		gtk_widget_hide(show_cmd);
+		goto run_dialog;
+	}
+
 	gtk_widget_destroy (GTK_WIDGET (dialog));
 }
 
@@ -957,7 +983,7 @@ void xa_new_archive (GtkMenuItem *menuitem,gpointer user_data)
 	if (current_page == -1)
 		return;
 
-	archive[current_page] = xa_new_archive_dialog (NULL,archive,FALSE);
+	archive[current_page] = xa_new_archive_dialog(NULL, archive);
 
 	if (archive[current_page] == NULL)
 		return;
@@ -976,7 +1002,6 @@ int xa_show_message_dialog (GtkWindow *window,int mode,int type,int button,const
 	int response;
 
 	dialog = gtk_message_dialog_new (window,mode,type,button,"%s",message1);
-	gtk_dialog_set_default_response (GTK_DIALOG (dialog),GTK_RESPONSE_NO);
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),"%s",message2);
 	response = gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_destroy (GTK_WIDGET (dialog));
@@ -1288,7 +1313,7 @@ void xa_close_archive (GtkWidget *widget, gpointer page)
 		xa_disable_delete_buttons (FALSE);
 		xa_set_button_state(1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, NULL, 0);
 		xa_set_window_title (xa_main_window,NULL);
-		gtk_tree_store_clear(GTK_TREE_STORE(archive_dir_model));
+		gtk_tree_store_clear(archive_dir_treestore);
 		gtk_entry_set_text(GTK_ENTRY(location_entry),"");
 		gtk_label_set_text(GTK_LABEL(total_label),_("Select \"New\" to create or \"Open\" to open an archive"));
 		gtk_widget_hide(selected_frame);
@@ -1760,6 +1785,13 @@ ArchiveType xa_detect_archive_type (const gchar *filename)
 
 	if (memcmp(magic, "7z" "\xbc\xaf\x27\x1c", 6) == 0)
 		xa.type = XARCHIVETYPE_7ZIP;
+	else if (memcmp(magic, "!<arch>\n", 8) == 0)
+	{
+		xa.type = XARCHIVETYPE_AR;
+
+		if (memcmp(magic + 8, "debian", 6) == 0)
+			xa.tag = 'd';
+	}
 	else if (memcmp(magic, "\x60\xea", 2) == 0)
 		xa.type = XARCHIVETYPE_ARJ;
 	else if (memcmp(magic, "BZh", 3) == 0)
@@ -1778,8 +1810,6 @@ ArchiveType xa_detect_archive_type (const gchar *filename)
 			/* different endianness */
 			xa.tag = 'E';
 	}
-	else if (memcmp(magic, "!<arch>\ndebian", 14) == 0)
-		xa.type = XARCHIVETYPE_DEB;
 	else if (memcmp(magic, "\x1f\x8b", 2) == 0 ||
 	         memcmp(magic, "\x1f\x9e", 2) == 0)
 		xa.type = XARCHIVETYPE_GZIP;
@@ -1814,7 +1844,8 @@ ArchiveType xa_detect_archive_type (const gchar *filename)
 	else if (memcmp(magic, "\xfd" "7zXZ" "\x00", 6) == 0)
 		xa.type = XARCHIVETYPE_XZ;
 	else if (memcmp(magic, "PK" "\x03\x04", 4) == 0 ||
-	         memcmp(magic, "PK" "\x05\x06", 4) == 0)
+	         memcmp(magic, "PK" "\x05\x06", 4) == 0 ||
+	         memcmp(magic + 4, "PK" "\x01\x02", 4) == 0)
 	{
 		xa.type = XARCHIVETYPE_ZIP;
 
@@ -1831,6 +1862,8 @@ ArchiveType xa_detect_archive_type (const gchar *filename)
 		else if (g_str_has_suffix(filename, ".xpi"))
 			xa.tag = 'x';
 	}
+	else if (g_str_has_suffix(filename, ".exe") && (memcmp(magic, "MZ", 2) == 0))
+		xa = exetype(file);
 	else if (memcmp(magic + 1, "\xb5\x2f\xfd", 3) == 0 &&
 	         (*magic == '\x1e' || (*magic >= '\x22' && *magic <= '\x28')))
 		xa.type = XARCHIVETYPE_ZSTD;
@@ -2265,7 +2298,7 @@ void on_drag_data_received (GtkWidget *widget,GdkDragContext *context,int x,int
 		idx = xa_get_new_archive_idx();
 		if (idx == -1)
 			return;
-		archive[idx] = xa_new_archive_dialog (filename,archive,TRUE);
+		archive[idx] = xa_new_archive_dialog(filename, archive);
 		if (archive[idx] == NULL)
 			return;
 		xa_add_page (archive[idx]);
@@ -2405,7 +2438,6 @@ void xa_show_archive_comment (GtkMenuItem *menuitem,gpointer user_data)
 	GtkWidget *textview;
 	GtkWidget *dialog_vbox1;
 	GtkWidget *scrolledwindow1;
-	GtkWidget *dialog_action_area1;
 	GtkWidget *tmp_image,*file,*clear,*close,*cancel,*file_hbox,*file_label;
 	GtkWidget *alignment2;
 	GtkTextBuffer *textbuffer;
@@ -2432,9 +2464,6 @@ void xa_show_archive_comment (GtkMenuItem *menuitem,gpointer user_data)
 	g_object_unref (textbuffer);
 	gtk_container_add (GTK_CONTAINER (scrolledwindow1),textview);
 
-	dialog_action_area1 = gtk_dialog_get_action_area(GTK_DIALOG(comment_dialog));
-	gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area1),GTK_BUTTONBOX_END);
-
 	clear = gtk_button_new_from_stock ("gtk-clear");
 	gtk_dialog_add_action_widget (GTK_DIALOG (comment_dialog),clear,0);
 	g_signal_connect (G_OBJECT (clear),"clicked",G_CALLBACK (xa_clear_comment_window),textbuffer);
@@ -2844,12 +2873,16 @@ void xa_update_window_with_archive_entries (XArchive *archive,XEntry *entry)
 	GtkTreeIter iter;
 	guint i;
 	gpointer current_column;
-	gchar *filename;
+	gchar *location_path = NULL, *filename;
 	gint size;
 	gchar *entry_utf8;
 
 	if (archive->status == XARCHIVESTATUS_RELOAD && archive->location_path != NULL)
+	{
 		entry = xa_find_entry_from_dirpath(archive, archive->location_path);
+
+		if (entry) location_path = g_strdup(archive->location_path);
+	}
 	else
 		archive->current_entry = entry;
 
@@ -2869,7 +2902,7 @@ void xa_update_window_with_archive_entries (XArchive *archive,XEntry *entry)
 	}
 	else
 	{
-		reload = FALSE;
+		reload = (archive->status == XARCHIVESTATUS_RELOAD);
 		gtk_widget_set_sensitive(back_button, archive->back != NULL);
 		gtk_widget_set_sensitive(up_button,TRUE);
 		gtk_widget_set_sensitive(home_button,TRUE);
@@ -2945,6 +2978,16 @@ void xa_update_window_with_archive_entries (XArchive *archive,XEntry *entry)
 		entry = entry->next;
 	}
 	xa_fill_dir_sidebar(archive, reload);
+
+	if (location_path)
+	{
+		entry = xa_find_entry_from_dirpath(archive, location_path);
+		xa_block_signal_dir_treeview_selection(TRUE);
+		xa_dir_sidebar_select_row(entry);
+		xa_block_signal_dir_treeview_selection(FALSE);
+		g_free(location_path);
+	}
+
 	xa_set_statusbar_message_for_displayed_rows(archive);
 }
 
